@@ -32,8 +32,8 @@
 #endif
 
 /* Set Version */
-#define CARLA_VERSION_HEX    0x020500
-#define CARLA_VERSION_STRING "2.5.0"
+#define CARLA_VERSION_HEX    0x020502
+#define CARLA_VERSION_STRING "2.5.2"
 #define CARLA_VERSION_STRMIN "2.5"
 
 /* Check OS */
@@ -76,8 +76,8 @@
 # if __cplusplus >= 201103L || (defined(__GNUC__) && (__GNUC__ * 100 + __GNUC_MINOR__) >= 405 && defined(__GXX_EXPERIMENTAL_CXX0X__)) || __has_extension(cxx_noexcept)
 #  define CARLA_PROPER_CPP11_SUPPORT
 #  if (defined(__GNUC__) && (__GNUC__ * 100 + __GNUC_MINOR__) < 407 && ! defined(__clang__)) || (defined(__clang__) && ! __has_extension(cxx_override_control))
-#   define override // gcc4.7+ only
-#   define final    // gcc4.7+ only
+#   define override /* gcc4.7+ only */
+#   define final    /* gcc4.7+ only */
 #  endif
 # endif
 #endif
